;; Generated package description from dape.el  -*- no-byte-compile: t -*-
(define-package "dape" "0.8.1.0.20240316.133832" "Debug Adapter Protocol for Emacs" '((emacs "29.1") (jsonrpc "1.0.25")) :commit "f43be7877bb2e3d441fd33525b9a01507d244ba5" :maintainer '("Daniel Pettersson" . "daniel@dpettersson.net") :url "https://github.com/svaante/dape")
